#
# spec file for package python-snowballstemmer
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
%global skip_python2 1
%{?sle15_python_module_pythons}
Name:           python-snowballstemmer
Version:        2.2.0
Release:        2.10
Summary:        16 stemmer algorithms
License:        BSD-3-Clause
Group:          Development/Languages/Python
URL:            https://github.com/shibukawa/snowball_py
Source:         https://files.pythonhosted.org/packages/source/s/snowballstemmer/snowballstemmer-%{version}.tar.gz
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
BuildArch:      noarch
%python_subpackages

%description
This package provides 16 stemmer algorithms (15 + Poerter English
stemmer) generated from Snowball algorithms.  It includes following
language algorithms: Danish, Dutch, English (Standard, Porter),
Finnish, French, German, Hungarian, Italian, Norwegian, Portuguese,
Romanian, Russian, Spanish, Swedish, Turkish. This is a pure Python
stemming library. If PyStemmer is available, this module uses it to
accelerate.

%prep
%setup -q -n snowballstemmer-%{version}

%build
%python_build

%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%files %{python_files}
%{python_sitelib}/*
%doc README.rst
%license COPYING

%changelog
* Fri Apr 21 2023 Dirk Müller <dmueller@suse.com>
- add sle15_python_module_pythons (jsc#PED-68)
* Thu Apr 13 2023 Matej Cepl <mcepl@suse.com>
- Make calling of %%{sle15modernpython} optional.
* Mon Dec  6 2021 Dirk Müller <dmueller@suse.com>
- update to 2.2.0:
  * Python 2 is no longer actively supported
  * Fix code generated for division.
  * C#: An `among` without functions is now generated as `static` and groupings
    are now generated as constant.
  * Constant numeric subexpressions and constant numeric tests are now
    evaluated at Snowball compile time.
  * german2: Fix handling of `qu` to match algorithm description.
  * arabic: Handle exception cases in the among they're exceptions to.
  * greek: Remove unused slice setting, handle exception cases in the among
    they're exceptions to
  * hindi: Eliminate the need for variable `p`.
  * irish: Minor optimisation in setting `pV` and `p1`.
* Sat Jan 23 2021 Dirk Müller <dmueller@suse.com>
- update to 2.1.0:
  * Add Serbian stemmer from stef4np (#113).
  * Add Yiddish stemmer from Assaf Urieli (#137).
  * Add Armenian stemmer from Astghik Mkrtchyan.  It's been on the website for
    over a decade, and included in Xapian for over 9 years without any negative
    feedback.
  * kraaij_pohlmann: Use `$v = limit` instead of `do (tolimit setmark v)` since
    this generates simpler code, and also matches the code other algorithm
    implementations use.
    Probably for languages like C with optimising compilers the compiler
    will generate equivalent code anyway, but e.g. for Python this should be
    an improvement.
* Fri Dec 20 2019 Dirk Mueller <dmueller@suse.com>
- update to 2.0.0:
  * Simplified generated code for ``repeat`` and ``atleast`` commands.
  * Implemented “go grouping” optimisation.
  * Removed caching layer (#114).
  * Enabled building wheels (#115).
  * Updated package README.
* Tue Sep 10 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 1.9.1:
  * provide license file in the tarball
* Tue Aug 27 2019 Jan Engelhardt <jengelh@inai.de>
- Avoid self-reference in summary.
* Fri Aug  2 2019 pgajdos@suse.com
- version update to 1.9.0
  * no upstream change log
  * relicensed to BSD-3-Clause, se README.rst
- added sources
  https://github.com/snowballstem/snowball/issues/102
  + COPYING
* Tue Dec  4 2018 Matej Cepl <mcepl@suse.com>
- Remove superfluous devel dependency for noarch package
* Thu Jun  1 2017 dmueller@suse.com
- update to 1.2.1:
  * fix syntax error
* Wed Apr  5 2017 tbechtold@suse.com
- Fix python_module macro definition
* Mon Dec 19 2016 jmatejek@suse.com
- update for multipython build
* Thu Apr 23 2015 mcihar@suse.cz
- Compatibility with SLE11
* Thu Apr  9 2015 termim@gmail.com
- copied from python3-snowballstemmer
* Sun Mar 15 2015 arun@gmx.de
- initial version
